@@ -28,9 +28,10 @@
 #ifndef LV2_UI_H
 #define LV2_UI_H
 
-#include <stdint.h>
+#include "lv2/core/lv2.h"
 
-#include "lv2/lv2plug.in/ns/lv2core/lv2.h"
+#include <stdbool.h>
+#include <stdint.h>
 
 #define LV2_UI_URI    "http://lv2plug.in/ns/extensions/ui"  ///< http://lv2plug.in/ns/extensions/ui
 #define LV2_UI_PREFIX LV2_UI_URI "#"                        ///< http://lv2plug.in/ns/extensions/ui#
@@ -73,8 +74,6 @@
 
 #ifdef __cplusplus
 extern "C" {
-#else
-#    include <stdbool.h>
 #endif
 
 /**
